@@ -9,19 +9,19 @@ HTMLWidgets.widget({
       .attr("width", width)
       .attr("height", height)
       .append("g");
-    
-    return d3.layout.cluster();
+
+    return d3.cluster();
 
   },
 
   resize: function(el, width, height, tree) {
-    
+
     var s = d3.select(el).selectAll("svg")
       .attr("width", width)
       .attr("height", height);
-    
+
     var margins = s.attr("margins");
-    
+
     var top = parseInt(margins.top),
       right = parseInt(margins.right),
       bottom = parseInt(margins.bottom),
@@ -31,11 +31,11 @@ HTMLWidgets.widget({
     width = width - right - left;
 
     if (s.attr("treeOrientation") == "horizontal") {
-      tree.size([height, width]); 
+      tree.size([height, width]);
     } else {
       tree.size([width, height]);
     }
-    
+
     var svg = d3.select(el).selectAll("svg").select("g")
       .attr("transform", "translate(" + left + "," + top + ")");
 
@@ -56,12 +56,12 @@ HTMLWidgets.widget({
       width = parseInt(s.attr("width")) - right - left;
 
     if (s.attr("treeOrientation") == "horizontal") {
-      tree.size([height, width]); 
+      tree.size([height, width]);
     } else {
       tree.size([width, height]);
     }
 
-    var zoom = d3.behavior.zoom();
+    var zoom = d3.zoom();
 
     var svg = d3.select(el).select("svg");
     svg.selectAll("*").remove();
@@ -70,107 +70,86 @@ HTMLWidgets.widget({
       .append("g").attr("class","zoom-layer")
       .append("g")
       .attr("transform", "translate(" + left + "," + top + ")");
-      
+
     if (x.options.zoom) {
        zoom.on("zoom", function() {
-         d3.select(el).select(".zoom-layer").attr("transform",
-           "translate(" + d3.event.translate + ")"+
-           " scale(" + d3.event.scale + ")");
+         d3.select(el).select(".zoom-layer")
+          .attr("transform", d3.event.transform);
        });
 
        d3.select(el).select("svg")
          .attr("pointer-events", "all")
          .call(zoom);
- 
+
      } else {
        zoom.on("zoom", null);
      }
 
-    var root = x.root;
-    
-    var xs = [];   
-    var ys = [];   
-    function getXYfromJSONTree(node){           
-       xs.push(node.x);          
-       ys.push(node.y);           
-       if(typeof node.children != 'undefined') {                   
-          for (var j in node.children) {                           
-             getXYfromJSONTree(node.children[j]);                   
-          }           
-       }   
-    }   
-    var ymax = Number.MIN_VALUE;   
-    var ymin = Number.MAX_VALUE;
-    
-    getXYfromJSONTree(root);          
-    var nodes = tree.nodes(root);           
-    var links = tree.links(nodes);           
-    nodes.forEach( function(d,i){                   
-      if(typeof xs[i] != 'undefined') {                           
-         d.x = xs[i];                   
-      }                   
-      if(typeof ys[i] != 'undefined') {                           
-         d.y = ys[i];                   
-      }           
-    });           
-    nodes.forEach( function(d) {                   
-      if(d.y > ymax)
-         ymax = d.y;
-      if(d.y < ymin)                           
-         ymin = d.y;           
-    });
+    var root = d3.hierarchy(x.root);
+    tree(root);
+
+    var ymax = d3.max(root.descendants(), function(d) { return d.data.y; });
+    var ymin = d3.min(root.descendants(), function(d) { return d.data.y; });
 
     if (s.attr("treeOrientation") == "horizontal") {
-      fxinv = d3.scale.linear().domain([ymin, ymax]).range([0, width]);
-      fx = d3.scale.linear().domain([ymax, ymin]).range([0, width]);
+      fxinv = d3.scaleLinear().domain([ymin, ymax]).range([0, width]);
+      fx = d3.scaleLinear().domain([ymax, ymin]).range([0, width]);
     } else {
-      fxinv = d3.scale.linear().domain([ymin, ymax]).range([0, height]);
-      fx = d3.scale.linear().domain([ymax, ymin]).range([0, height]);
+      fxinv = d3.scaleLinear().domain([ymin, ymax]).range([0, height]);
+      fx = d3.scaleLinear().domain([ymax, ymin]).range([0, height]);
     }
 
     // draw links
     var link = svg.selectAll(".link")
-      .data(links)
+      .data(root.links())
       .enter().append("path")
       .style("fill", "none")
       .style("stroke", "#ccc")
       .style("opacity", "0.55")
       .style("stroke-width", "1.5px");
-      
+
     if (x.options.linkType == "elbow") {
       if (s.attr("treeOrientation") == "horizontal") {
         link.attr("d", function(d, i) {
-          return "M" + fx(d.source.y) + "," + d.source.x
-            + "V" + d.target.x + "H" + fx(d.target.y);
+          return "M" + fx(d.source.data.y) + "," + d.source.x
+            + "V" + d.target.x + "H" + fx(d.target.data.y);
         });
       } else {
         link.attr("d", function(d, i) {
-          return "M" + d.source.x + "," + fx(d.source.y)
-            + "H" + d.target.x + "V" + fx(d.target.y);
+          return "M" + d.source.x + "," + fx(d.source.data.y)
+            + "H" + d.target.x + "V" + fx(d.target.data.y);
         });
       }
     } else {
       if (s.attr("treeOrientation") == "horizontal") {
-        link.attr("d", d3.svg.diagonal()
-          .projection(function(d) { return [fx(d.y), d.x]; }));
+        link.attr("d", function(d, i) {
+          return "M" + fx(d.source.data.y) + "," + d.source.x
+                + "C" + (fx(d.source.data.y) + fx(d.target.data.y)) / 2 + "," + d.source.x
+                + " " + (fx(d.source.data.y) + fx(d.target.data.y)) / 2 + "," + d.target.x
+                + " " + fx(d.target.data.y) + "," + d.target.x;
+        });
       } else {
-        link.attr("d", d3.svg.diagonal()
-          .projection(function(d) { return [d.x, fx(d.y)]; }));
+        link.attr("d", function(d, i) {
+          return "M" + d.source.x + "," + fx(d.source.data.y)
+                + "C" + (d.source.x + d.target.x) / 2 + "," + fx(d.source.data.y)
+                + " " + (d.source.x + d.target.x) / 2 + "," + fx(d.target.data.y)
+                + " " + d.target.x + "," + fx(d.target.data.y);
+        });
       }
     }
 
     // draw nodes
     var node = svg.selectAll(".node")
-      .data(nodes)
+      .data(root.descendants())
       .enter().append("g")
       .attr("class", "node")
       .on("mouseover", mouseover)
       .on("mouseout", mouseout);
-      
+
     if (s.attr("treeOrientation") == "horizontal") {
-      node.attr("transform", function(d) { return "translate(" + fx(d.y) + "," + d.x + ")"; });
+      node.attr("transform", function(d) { return "translate(" + fx(d.data.y) + "," + d.x + ")"; });
     } else {
-      node.attr("transform", function(d) { return "translate(" + d.x + "," + fx(d.y) + ")"; });
+      node.attr("transform", function(d) { return "translate(" + d.x + "," + fx(d.data.y) + ")"; });
     }
 
     // node circles
@@ -185,10 +164,10 @@ HTMLWidgets.widget({
     node.append("text")
       .attr("transform", "rotate(" + x.options.textRotate + ")")
       .style("font", x.options.fontSize + "px serif")
-      .style("opacity", function(d) { return d.textOpacity; })
-      .style("fill", function(d) { return d.textColour; })
-      .text(function(d) { return d.name; });
-      
+      .style("opacity", function(d) { return d.data.textOpacity; })
+      .style("fill", function(d) { return d.data.textColour; })
+      .text(function(d) { return d.data.name; });
+
     if (s.attr("treeOrientation") == "horizontal") {
       node.select("text")
         .attr("dx", function(d) { return d.children ? -8 : 8; })
@@ -206,7 +185,7 @@ HTMLWidgets.widget({
       d3.select(this).select("circle").transition()
         .duration(750)
         .attr("r", 9);
-        
+
       d3.select(this).select("text").transition()
         .duration(750)
         .style("stroke-width", ".5px")
@@ -219,7 +198,7 @@ HTMLWidgets.widget({
       d3.select(this).select("circle").transition()
         .duration(750)
         .attr("r", 4.5);
-        
+
       d3.select(this).select("text").transition()
         .duration(750)
         .style("font", x.options.fontSize + "px serif")
